@@ -4,7 +4,6 @@ extern crate deq_macros;
 pub use deq_core::*;
 pub use deq_macros::*;
 
-
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -14,12 +13,17 @@ mod tests {
     struct Test {
         x: i64,
         y: i64,
-        z: i64
+        z: i64,
     }
 
     #[test]
     fn it_should_start_a_transaction() {
-        let mut t = Test {x: 100, y: 200, z: 300, transaction_data: TransactionData::new()};
+        let mut t = Test {
+            x: 100,
+            y: 200,
+            z: 300,
+            transaction_data: TransactionData::new(),
+        };
         t.begin();
         t.x += 20;
         let _ = t.commit().unwrap();
@@ -30,7 +34,12 @@ mod tests {
 
     #[test]
     fn it_should_revert_a_transaction() {
-        let mut t = Test {x: 100, y: 200, z: 300, transaction_data: TransactionData::new()};
+        let mut t = Test {
+            x: 100,
+            y: 200,
+            z: 300,
+            transaction_data: TransactionData::new(),
+        };
         t.begin();
         t.x += 20;
         let _ = t.revert().unwrap();
@@ -41,7 +50,12 @@ mod tests {
 
     #[test]
     fn it_should_allow_many_transactions() {
-        let mut t = Test {x: 100, y: 200, z: 300, transaction_data: TransactionData::new()};
+        let mut t = Test {
+            x: 100,
+            y: 200,
+            z: 300,
+            transaction_data: TransactionData::new(),
+        };
         t.begin();
         t.x += 20;
         t.begin();
@@ -56,11 +70,15 @@ mod tests {
         assert_eq!(t.len(), 0);
     }
 
-
     #[test]
     #[should_panic]
     fn it_should_not_revert_if_transaction_was_not_started() {
-        let mut t = Test {x: 100, y: 200, z: 300, transaction_data: TransactionData::new()};
+        let mut t = Test {
+            x: 100,
+            y: 200,
+            z: 300,
+            transaction_data: TransactionData::new(),
+        };
         t.x += 20;
         let _ = t.revert().unwrap();
 
@@ -71,7 +89,12 @@ mod tests {
     #[test]
     #[should_panic]
     fn it_should_not_commit_if_transaction_was_not_started() {
-        let mut t = Test {x: 100, y: 200, z: 300, transaction_data: TransactionData::new()};
+        let mut t = Test {
+            x: 100,
+            y: 200,
+            z: 300,
+            transaction_data: TransactionData::new(),
+        };
         t.x += 20;
         let _ = t.commit().unwrap();
 
